rnalysis.filtering.HTCountFilter.filter\_by\_bigtable\_group
============================================================

.. currentmodule:: rnalysis.filtering

.. automethod:: HTCountFilter.filter_by_bigtable_group